@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.023-3-g59b8951
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.024-3-g0b6c8ae
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.024'; # TRIAL
+our $VERSION = '0.025'; # TRIAL
 
 use Moose;
 with
@@ -272,10 +272,10 @@ sub gather_files {
 
             my $file = (first { $_->name eq $path } @{ $self->zilla->files })
                 # TODO this requires a new release of ModuleIncluder
-                # || ($self->include_modules([ $module ], '5.006'))[0];
+                # || ($self->include_modules([ $module ], '5.006001'))[0];
                 || do {
                     $self->log([ 'inlining %s into inc/', $module ]);
-                    $self->include_modules([ $module ], version->new('5.006'));
+                    $self->include_modules([ $module ], version->new('5.006001'));
                     first { $_->name eq $path } @{ $self->zilla->files };
                 };
 
@@ -383,7 +383,7 @@ sub _warn_include_subs
 {
     my ($self, @include_subs) = @_;
 
-    $self->log(colored('The use of ' . $_ . ' is not advised. Please consult the documentation!', 'bright_yellow'))
+    $self->log(colored('Use ' . $_ . ' with great care! Please consult the documentation!', 'bright_yellow'))
         foreach grep { exists $warn_include_sub{$_} } @include_subs;
 }
 
@@ -401,7 +401,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
